package javax.swing.plaf.metal;

import java.awt.Component;
import java.awt.Container;
import java.awt.LayoutManager;
import javax.swing.JSplitPane;
import javax.swing.JComponent;
import java.awt.Cursor;
import javax.swing.border.Border;
import javax.swing.JButton;
import java.awt.Dimension;
import java.awt.Insets;
import java.awt.Rectangle;
import java.awt.Graphics;
import javax.swing.UIManager;
import javax.swing.plaf.basic.BasicSplitPaneUI;
import java.awt.Color;
import javax.swing.plaf.basic.BasicSplitPaneDivider;

class MetalSplitPaneDivider extends BasicSplitPaneDivider
{
    private MetalBumps bumps;
    private MetalBumps focusBumps;
    private int inset;
    private Color controlColor;
    private Color primaryControlColor;
    
    public MetalSplitPaneDivider(BasicSplitPaneUI ui) {
        super(ui);
        this.bumps = new MetalBumps(10, 10, MetalLookAndFeel.getControlHighlight(), MetalLookAndFeel.getControlDarkShadow(), MetalLookAndFeel.getControl());
        this.focusBumps = new MetalBumps(10, 10, MetalLookAndFeel.getPrimaryControlHighlight(), MetalLookAndFeel.getPrimaryControlDarkShadow(), UIManager.getColor("SplitPane.dividerFocusColor"));
        this.inset = 2;
        this.controlColor = MetalLookAndFeel.getControl();
        this.primaryControlColor = UIManager.getColor("SplitPane.dividerFocusColor");
    }
    
    @Override
    public void paint(Graphics g) {
        MetalBumps metalBumps;
        if (this.splitPane.hasFocus()) {
            metalBumps = this.focusBumps;
            g.setColor(this.primaryControlColor);
        }
        else {
            metalBumps = this.bumps;
            g.setColor(this.controlColor);
        }
        Rectangle clipBounds = g.getClipBounds();
        Insets insets = this.getInsets();
        g.fillRect(clipBounds.x, clipBounds.y, clipBounds.width, clipBounds.height);
        Dimension size = this.getSize();
        size.width -= this.inset * 2;
        size.height -= this.inset * 2;
        int inset = this.inset;
        int inset2 = this.inset;
        if (insets != null) {
            size.width -= insets.left + insets.right;
            size.height -= insets.top + insets.bottom;
            inset += insets.left;
            inset2 += insets.top;
        }
        metalBumps.setBumpArea(size);
        metalBumps.paintIcon(this, g, inset, inset2);
        super.paint(g);
    }
    
    @Override
    protected JButton createLeftOneTouchButton() {
        JButton button = new JButton() {
            int[][] buffer = { { 0, 0, 0, 2, 2, 0, 0, 0, 0 }, { 0, 0, 2, 1, 1, 1, 0, 0, 0 }, { 0, 2, 1, 1, 1, 1, 1, 0, 0 }, { 2, 1, 1, 1, 1, 1, 1, 1, 0 }, { 0, 3, 3, 3, 3, 3, 3, 3, 3 } };
            
            @Override
            public void setBorder(Border border) {
            }
            
            @Override
            public void paint(Graphics graphics) {
                if (MetalSplitPaneDivider.this.getSplitPaneFromSuper() != null) {
                    int oneTouchSizeFromSuper = MetalSplitPaneDivider.this.getOneTouchSizeFromSuper();
                    int orientationFromSuper = MetalSplitPaneDivider.this.getOrientationFromSuper();
                    int min = Math.min(MetalSplitPaneDivider.this.getDividerSize(), oneTouchSizeFromSuper);
                    Color[] array = { this.getBackground(), MetalLookAndFeel.getPrimaryControlDarkShadow(), MetalLookAndFeel.getPrimaryControlInfo(), MetalLookAndFeel.getPrimaryControlHighlight() };
                    graphics.setColor(this.getBackground());
                    if (this.isOpaque()) {
                        graphics.fillRect(0, 0, this.getWidth(), this.getHeight());
                    }
                    if (this.getModel().isPressed()) {
                        array[1] = array[2];
                    }
                    if (orientationFromSuper == 0) {
                        for (int k = 1; k <= this.buffer[0].length; ++k) {
                            for (int l = 1; l < min; ++l) {
                                if (this.buffer[l - 1][k - 1] != 0) {
                                    graphics.setColor(array[this.buffer[l - 1][k - 1]]);
                                    graphics.drawLine(k, l, k, l);
                                }
                            }
                        }
                    }
                    else {
                        for (int i = 1; i <= this.buffer[0].length; ++i) {
                            for (int j = 1; j < min; ++j) {
                                if (this.buffer[j - 1][i - 1] != 0) {
                                    graphics.setColor(array[this.buffer[j - 1][i - 1]]);
                                    graphics.drawLine(j, i, j, i);
                                }
                            }
                        }
                    }
                }
            }
            
            @Override
            public boolean isFocusTraversable() {
                return false;
            }
        };
        button.setRequestFocusEnabled(false);
        button.setCursor(Cursor.getPredefinedCursor(0));
        button.setFocusPainted(false);
        button.setBorderPainted(false);
        this.maybeMakeButtonOpaque(button);
        return button;
    }
    
    private void maybeMakeButtonOpaque(JComponent component) {
        Object value = UIManager.get("SplitPane.oneTouchButtonsOpaque");
        if (value != null) {
            component.setOpaque((boolean)value);
        }
    }
    
    @Override
    protected JButton createRightOneTouchButton() {
        JButton button = new JButton() {
            int[][] buffer = { { 2, 2, 2, 2, 2, 2, 2, 2 }, { 0, 1, 1, 1, 1, 1, 1, 3 }, { 0, 0, 1, 1, 1, 1, 3, 0 }, { 0, 0, 0, 1, 1, 3, 0, 0 }, { 0, 0, 0, 0, 3, 0, 0, 0 } };
            
            @Override
            public void setBorder(Border border) {
            }
            
            @Override
            public void paint(Graphics graphics) {
                if (MetalSplitPaneDivider.this.getSplitPaneFromSuper() != null) {
                    int oneTouchSizeFromSuper = MetalSplitPaneDivider.this.getOneTouchSizeFromSuper();
                    int orientationFromSuper = MetalSplitPaneDivider.this.getOrientationFromSuper();
                    int min = Math.min(MetalSplitPaneDivider.this.getDividerSize(), oneTouchSizeFromSuper);
                    Color[] array = { this.getBackground(), MetalLookAndFeel.getPrimaryControlDarkShadow(), MetalLookAndFeel.getPrimaryControlInfo(), MetalLookAndFeel.getPrimaryControlHighlight() };
                    graphics.setColor(this.getBackground());
                    if (this.isOpaque()) {
                        graphics.fillRect(0, 0, this.getWidth(), this.getHeight());
                    }
                    if (this.getModel().isPressed()) {
                        array[1] = array[2];
                    }
                    if (orientationFromSuper == 0) {
                        for (int k = 1; k <= this.buffer[0].length; ++k) {
                            for (int l = 1; l < min; ++l) {
                                if (this.buffer[l - 1][k - 1] != 0) {
                                    graphics.setColor(array[this.buffer[l - 1][k - 1]]);
                                    graphics.drawLine(k, l, k, l);
                                }
                            }
                        }
                    }
                    else {
                        for (int i = 1; i <= this.buffer[0].length; ++i) {
                            for (int j = 1; j < min; ++j) {
                                if (this.buffer[j - 1][i - 1] != 0) {
                                    graphics.setColor(array[this.buffer[j - 1][i - 1]]);
                                    graphics.drawLine(j, i, j, i);
                                }
                            }
                        }
                    }
                }
            }
            
            @Override
            public boolean isFocusTraversable() {
                return false;
            }
        };
        button.setCursor(Cursor.getPredefinedCursor(0));
        button.setFocusPainted(false);
        button.setBorderPainted(false);
        button.setRequestFocusEnabled(false);
        this.maybeMakeButtonOpaque(button);
        return button;
    }
    
    int getOneTouchSizeFromSuper() {
        return 6;
    }
    
    int getOneTouchOffsetFromSuper() {
        return 2;
    }
    
    int getOrientationFromSuper() {
        return super.orientation;
    }
    
    JSplitPane getSplitPaneFromSuper() {
        return super.splitPane;
    }
    
    JButton getLeftButtonFromSuper() {
        return super.leftButton;
    }
    
    JButton getRightButtonFromSuper() {
        return super.rightButton;
    }
    
    public class MetalDividerLayout implements LayoutManager
    {
        @Override
        public void layoutContainer(Container container) {
            JButton leftButtonFromSuper = MetalSplitPaneDivider.this.getLeftButtonFromSuper();
            JButton rightButtonFromSuper = MetalSplitPaneDivider.this.getRightButtonFromSuper();
            JSplitPane splitPaneFromSuper = MetalSplitPaneDivider.this.getSplitPaneFromSuper();
            int orientationFromSuper = MetalSplitPaneDivider.this.getOrientationFromSuper();
            int oneTouchSizeFromSuper = MetalSplitPaneDivider.this.getOneTouchSizeFromSuper();
            int oneTouchOffsetFromSuper = MetalSplitPaneDivider.this.getOneTouchOffsetFromSuper();
            Insets insets = MetalSplitPaneDivider.this.getInsets();
            if (leftButtonFromSuper != null && rightButtonFromSuper != null && container == MetalSplitPaneDivider.this) {
                if (splitPaneFromSuper.isOneTouchExpandable()) {
                    if (orientationFromSuper == 0) {
                        int n2 = (insets != null) ? insets.top : 0;
                        int dividerSize2 = MetalSplitPaneDivider.this.getDividerSize();
                        if (insets != null) {
                            dividerSize2 -= insets.top + insets.bottom;
                        }
                        int min2 = Math.min(dividerSize2, oneTouchSizeFromSuper);
                        leftButtonFromSuper.setBounds(oneTouchOffsetFromSuper, n2, min2 * 2, min2);
                        rightButtonFromSuper.setBounds(oneTouchOffsetFromSuper + oneTouchSizeFromSuper * 2, n2, min2 * 2, min2);
                    }
                    else {
                        int dividerSize = MetalSplitPaneDivider.this.getDividerSize();
                        int n = (insets != null) ? insets.left : 0;
                        if (insets != null) {
                            dividerSize -= insets.left + insets.right;
                        }
                        int min = Math.min(dividerSize, oneTouchSizeFromSuper);
                        leftButtonFromSuper.setBounds(n, oneTouchOffsetFromSuper, min, min * 2);
                        rightButtonFromSuper.setBounds(n, oneTouchOffsetFromSuper + oneTouchSizeFromSuper * 2, min, min * 2);
                    }
                }
                else {
                    leftButtonFromSuper.setBounds(-5, -5, 1, 1);
                    rightButtonFromSuper.setBounds(-5, -5, 1, 1);
                }
            }
        }
        
        @Override
        public Dimension minimumLayoutSize(Container container) {
            return new Dimension(0, 0);
        }
        
        @Override
        public Dimension preferredLayoutSize(Container container) {
            return new Dimension(0, 0);
        }
        
        @Override
        public void removeLayoutComponent(Component component) {
        }
        
        @Override
        public void addLayoutComponent(String s, Component component) {
        }
    }
}
